'use strict';

/* For ESLint: List any global identifiers used in this file below */
/* global browser, localizePage, generalInit, filtersInit, customizeInit, supportInit,
translate, getStorageCookie, setStorageCookie, THIRTY_MINUTES_IN_MILLISECONDS */

const BG = browser.extension.getBackgroundPage();
const { Fennec: localFennec } = BG;
let optionalSettings = {};

function loadOptions() {
  // Check or uncheck each option.
  optionalSettings = BG.getSettings();
  localizePage();

  let currTabIndex = getStorageCookie('adblock_optiontab_index');
  if (!currTabIndex) {
    currTabIndex = 0;
    setStorageCookie('adblock_optiontab_index', currTabIndex, THIRTY_MINUTES_IN_MILLISECONDS);
  }

  $('#tabpages').tabs({
    active: currTabIndex,
    activate(event, ui) {
      setStorageCookie('adblock_optiontab_index', ui.newTab.index(), THIRTY_MINUTES_IN_MILLISECONDS);
      if (localFennec && $('#small_nav').css('display') !== 'none') {
        $('.ui-tabs-nav').css('display', 'none');
      }
    },
  }).show();
  if (!optionalSettings.show_advanced_options) {
    $('.advanced').remove();
  }

  // initialze each tab
  generalInit();
  filtersInit();
  customizeInit();
  supportInit();
  if (localFennec) {
    $('.desktop-only').hide();
    $('input[type="checkbox"]').css('line-height', '2.5em');
    $('.subscription').css('line-height', '2.5em');
  }
}

let language = '';
if ((typeof navigator.language !== 'undefined')
    && navigator.language) {
  [language] = navigator.language.match(/^[a-z]+/i);
}

function rightToLeft() {
  if (language === 'ar' || language === 'he') {
    $(window).resize(() => {
      if ($('.social').is(':hidden')) {
        $('#translation_credits').css({ margin: '0px 50%', width: '350px' });
        $('#paymentlink').css({ margin: '0px 50%', width: '350px' });
        $('#version_number').css({ margin: '20px 50%', width: '350px' });
      } else {
        $('#translation_credits').css('right', '0px');
        $('#paymentlink').css('right', '0px');
        $('#version_number').css({ right: '0px', padding: '0px' });
      }
    });

    $('li').css('float', 'right');
    $('#small_nav').css({ right: 'initial', left: '45px' });
    $('.ui-tabs .ui-tabs-nav li').css('float', 'right');
  } else {
    $('.ui-tabs .ui-tabs-nav li').css('float', 'left');
  }
}

function showMiniMenu() {
  let tabPages = $('#tabpages');
  let tabsNav = $('.ui-tabs-nav');
  let tabWrapper = $('#tab-wrapper');
  let smallNav = $('#small_nav');
  let uiTabs = $('.ui-tabs .ui-tabs-nav li');

  smallNav.click(() => {
    if (tabsNav.is(':hidden')) {
      uiTabs.css('float', 'none');
      tabWrapper.css('display', 'flex');
      if (language === 'ar' || language === 'he') {
        tabsNav.css({ right: 'auto', left: '40px' });
      }
      // Push content below the menu including when the menu wraps
      tabPages.animate({'padding-top': `${tabsNav.height() + 50}px`});
    } else {
      tabWrapper.fadeOut('fast');
      tabPages.animate({'padding-top':'50px'});
    }
  });

  $(window).resize(() => {
    if (smallNav.is(':hidden')) {
      if (language === 'ar' || language === 'he') {
        uiTabs.css('float', 'right');
        tabsNav.css({ right: 'auto', left: 'auto' });
      } else {
        uiTabs.css('float', 'left');
      }
      tabWrapper.css('display','flex');
    } else if (smallNav.is(':visible')) {
      tabWrapper.hide();
      tabPages.css({'padding-top':'50px'});
    }
  });
}

function setUserId() {
  BG.getAdblockUserId((userid) => {
    if (userid) {
      const paymentHREFhref = `https://getadblock.com/pay/?source=O&u=${userid}`;
      $('#paymentlink').attr('href', paymentHREFhref);
    }
  });
}

function displayTranslationCredit() {
  const fullLang = browser.i18n.getUILanguage().toLowerCase();
  const translators = [];
  const xhr = new XMLHttpRequest();
  xhr.open('GET', '../translators.json');
  xhr.onload = function onloadFunction() {
    const partialLang = fullLang.substring(0, 2);
    const chromeLang = `${partialLang}-${partialLang}`;
    const text = JSON.parse(xhr.responseText);
    let matchFound = false;

    for (const id in text) {
      // if matching id hasn't been found and id matches lang
      if (!matchFound && (partialLang === id || chromeLang === id || fullLang === id)) {
        matchFound = true;
        // Check if this language is professionally translated
        const professionalLang = text[id].professional;
        for (const translator in text[id].translators) {
          // If the language is not professionally translated, or if this translator
          // is a professional, then add the name to the list of credits
          if (!professionalLang || text[id].translators[translator].professional) {
            const name = text[id].translators[translator].credit;
            translators.push(` ${name}`);
          }
        }
      }
    }

    if (translators.length > 0) {
      $('#translator_credit').text(translate('translator_credit'));
      $('#translator_names').text(translators.toString());
    }
  };

  xhr.send();
}

function displayVersionNumber() {
  $('#version_number').text(translate('optionsversion', [BG.browser.runtime.getManifest().version]));
}

$(document).ready(() => {
  //    browser.i18n.initializeL10nData(function () {
  loadOptions();
  rightToLeft();
  showMiniMenu();
  setUserId();
  displayVersionNumber();
  displayTranslationCredit();
  //    });
});
